# ttblackjack

A simple blackjack poker game.

<img src="images/picture-01.png" width="300" />

## Install
Install from `wheel` or PyPI
```
pip3 install --user ttblackjack
# or
pipx install ttblackjack
```

## Help
```
ttblackjack --help
```